/* -*- mode: c++; c-basic-offset: 3; -*- */
#ifndef SENSE_MONITOR2_HH
#define SENSE_MONITOR2_HH

#include "DatEnv.hh"
#include "ranger.hh"
#include "OperStateCondList.hh"
#include "Trend.hh"
#include "MonServer.hh"
#include "autopipe.hh"
#include <fstream>

class sense_monitor2 : public DatEnv {
public:
   sense_monitor2(int argc, const char* argv[]);
   ~sense_monitor2(void);

   /** handle any interrupts for the monitor service.
    *  \brief Handle monitor interrupts.
    */
   void Attention(void);

   /** Clear previous results of all range tools.
    */
   void clear(void);

   /** Parse the json configuration file.
    *  \brief parse the configuration.
    *  \param file configuration file path.
    */
   void configure(const std::string& file);

   /** Write all the configuration parameters to the specified output stream
    *  in a human readable format.
    *  \brief Display configuration information.
    *  \param out Output stream to which the configuration will be written.
    */
   void display(std::ostream& out) const;

   /** Perform monitor processing on one stride of data.
    *  \brief Process one stride
    */
   void ProcessData(void);

   /** Write the html status document to the file path specified by mStatusFile.
    *  \brief Write status page.
    *  \param t effective time of writing.
    */
   void put_html(const Time& t) const;

   /** Reset filters and range calculations.
    *  \brief Reset monitor status after shipped data.
    */
   void reset(void);

private:
   typedef std::vector<ranger> ranger_vect;

private:
   std::string       monitorName;
   std::string       mChannel;
   std::string       mOscPath;
   std::string       mOscBreakCond;
   std::string       mOscGateCond;
   std::string       mTrendPath;
   std::string       mStatusFile;
   std::string       mCumulativeLog;
   double            mSampleRate;
   double            mStride;
   double            mHighPass;
   double            mHighPassDf;
   Interval          mHtmlUpdateInterval;
   std::string       mFilterDesign;
   auto_pipe         mResampler;
   auto_pipe         mConditioner;
   OperStateCondList mOsc;
   Trend             mTrend;
   ranger_vect       mRangers;
   bool              mEnableServer;
   MonServer         mServer;
   size_t            mNStride;
   Time              mStartTime;
   Time              mLastHtmlUpdate;
   std::ofstream     mCumLogStream;
};

#endif // !defined(SENSE_MONITOR2_HH)
